==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ScatterAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterTriangulationSeriesDescription } from "./ScatterTriangulationSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let ScatterAreaSeriesDescription = /*@__PURE__*/ (() => {
    class ScatterAreaSeriesDescription extends ScatterTriangulationSeriesDescription {
        constructor() {
            super();
            this.dw = null;
            this.d1 = null;
            this.dv = null;
            this.dz = null;
            this.d0 = null;
        }
        get_type() {
            return "ScatterAreaSeries";
        }
        get colorScale() {
            return this.dw;
        }
        set colorScale(a) {
            this.dw = a;
            this.e("ColorScale");
        }
        get colorMemberPath() {
            return this.d1;
        }
        set colorMemberPath(a) {
            this.d1 = a;
            this.e("ColorMemberPath");
        }
        get actualColorScale() {
            return this.dv;
        }
        set actualColorScale(a) {
            this.dv = a;
            this.e("ActualColorScale");
        }
        get colorMemberAsLegendLabel() {
            return this.dz;
        }
        set colorMemberAsLegendLabel(a) {
            this.dz = a;
            this.e("ColorMemberAsLegendLabel");
        }
        get colorMemberAsLegendUnit() {
            return this.d0;
        }
        set colorMemberAsLegendUnit(a) {
            this.d0 = a;
            this.e("ColorMemberAsLegendUnit");
        }
    }
    ScatterAreaSeriesDescription.$t = /*@__PURE__*/ markType(ScatterAreaSeriesDescription, 'ScatterAreaSeriesDescription', ScatterTriangulationSeriesDescription.$);
    return ScatterAreaSeriesDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ScatterAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ScatterTriangulationSeriesDescription } from "./ScatterTriangulationSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let ScatterAreaSeriesDescription = /*@__PURE__*/ (() => {
    class ScatterAreaSeriesDescription extends ScatterTriangulationSeriesDescription {
        get_type() {
            return "ScatterAreaSeries";
        }
        constructor() {
            super();
            this.fu = null;
            this.fz = null;
            this.ft = null;
            this.fx = null;
            this.fy = null;
        }
        get colorScale() {
            return this.fu;
        }
        set colorScale(a) {
            this.fu = a;
            this.g("ColorScale");
        }
        get colorMemberPath() {
            return this.fz;
        }
        set colorMemberPath(a) {
            this.fz = a;
            this.g("ColorMemberPath");
        }
        get actualColorScale() {
            return this.ft;
        }
        set actualColorScale(a) {
            this.ft = a;
            this.g("ActualColorScale");
        }
        get colorMemberAsLegendLabel() {
            return this.fx;
        }
        set colorMemberAsLegendLabel(a) {
            this.fx = a;
            this.g("ColorMemberAsLegendLabel");
        }
        get colorMemberAsLegendUnit() {
            return this.fy;
        }
        set colorMemberAsLegendUnit(a) {
            this.fy = a;
            this.g("ColorMemberAsLegendUnit");
        }
    }
    ScatterAreaSeriesDescription.$t = /*@__PURE__*/ markType(ScatterAreaSeriesDescription, 'ScatterAreaSeriesDescription', ScatterTriangulationSeriesDescription.$);
    return ScatterAreaSeriesDescription;
})();
